==> codesys_bridge-0.1.1-py3-none-any.whl: codesys_bridge/codesys_script_install.py <==
import os
import sys
import ctypes
import shutil
import json
import glob

def is_admin():
    try:
        return ctypes.windll.shell32.IsUserAnAdmin()
    except:
        return False

def get_installation_directories():
    """Returns a list of all Script Commands directories where we need to install"""
    directories = []
    
    # Get CODESYS directories
    codesys_base = os.path.join(os.environ.get('PROGRAMFILES', 'C:\\Program Files'), 'CODESYS 3.5')
    codesys_dirs = glob.glob(os.path.join(os.path.dirname(codesys_base), 'CODESYS 3.5.*'))
    for codesys_dir in codesys_dirs:
        directories.append(os.path.join(codesys_dir, 'CODESYS', 'Script Commands'))
    
    # Get SE Machine Expert directories
    se_base_dir = os.path.join(
        os.environ.get('PROGRAMFILES', 'C:\\Program Files'),
        'Schneider Electric',
        'EcoStruxure Machine Expert'
    )
    v2_dirs = glob.glob(os.path.join(se_base_dir, 'V2.*'))
    for v2_dir in v2_dirs:
        directories.append(os.path.join(v2_dir, 'LogicBuilder', 'Script Commands'))
    
    return directories

def install_to_directory(path, git_support_entry):
    """Install config and assets to a single directory"""
    print(f"\nInstalling to: {path}")
    
    # Create directory (recursive)
    os.makedirs(path, exist_ok=True)
    
    # Copy icon
    current_dir = os.path.dirname(os.path.abspath(__file__))
    icon_path = os.path.join(current_dir, 'assets', 'export_icon.ico')
    shutil.copy2(icon_path, os.path.join(path, 'export_icon.ico'))
    print(f"Copied export_icon.ico to {path}")
    
    # Update or create config.json
    config_dest = os.path.join(path, 'config.json')
    if os.path.exists(config_dest):
        with open(config_dest, 'r') as f:
            config = json.load(f)
        
        # Update or add Git Support entry
        for i, entry in enumerate(config):
            if entry.get('Name') == "CodeSys Bridge Script":
                config[i] = git_support_entry
                print(f"Updated existing CodeSys Bridge Script entry in config.json")
                break
        else:
            config.append(git_support_entry)
            print(f"Added CodeSys Bridge Script entry to config.json")
    else:
        config = [git_support_entry]
        print(f"Created new config.json with CodeSys Bridge Script entry")
    
    with open(config_dest, 'w') as f:
        json.dump(config, f, indent=4)

def copy_to_script_commands():
    # Get the directory of the current script
    current_dir = os.path.dirname(os.path.abspath(__file__))
    
    # Prepare our config entry
    git_support_entry = {
        "Name": "CodeSys Bridge Script",
        "Desc": "CodeSys Bridge Script",
        "Icon": "export_icon.ico",
        "Path": os.path.abspath(os.path.join(current_dir, 'codesys_bridge_script.py'))
    }
    
    # Get all installation directories
    directories = get_installation_directories()
    
    if not directories:
        print("No installation directories found!")
        return
    
    # Install to each directory
    for directory in directories:
        install_to_directory(directory, git_support_entry)

def main():
    if not is_admin():
        # ShellExecuteW returns an HINSTANCE (int) > 32 if successful
        result = ctypes.windll.shell32.ShellExecuteW(None, "runas", sys.argv[0], " ".join(sys.argv), None, 1)
        if result <= 32:  # Error codes are <= 32
            error_messages = {
                2: "File not found",
                5: "Access denied",
            }
            error_msg = error_messages.get(result, f"Ereror code ({result})")
            print(f"Failed to run {sys.argv[0]}: {error_msg}")
            sys.exit(1)
        sys.exit(0)
    
    try:
        copy_to_script_commands()
        print("Successfully installed script commands and assets")
    except Exception as e:
        import traceback
        print(f"Error during installation: {e}")
        traceback.print_exc()
        
        input("Press Enter to exit...")


if __name__ == "__main__":
    main()

==> codesys_bridge-0.1.2-py3-none-any.whl: codesys_bridge/codesys_script_install.py <==
import os
import sys
import ctypes
import shutil
import json
import glob

def is_admin():
    try:
        return ctypes.windll.shell32.IsUserAnAdmin()
    except:
        return False

def get_installation_directories():
    """Returns a list of all Script Commands directories where we need to install"""
    directories = []
    
    # Get CODESYS directories
    codesys_base = os.path.join(os.environ.get('PROGRAMFILES', 'C:\\Program Files'), 'CODESYS 3.5')
    codesys_dirs = glob.glob(os.path.join(os.path.dirname(codesys_base), 'CODESYS 3.5.*'))
    for codesys_dir in codesys_dirs:
        directories.append(os.path.join(codesys_dir, 'CODESYS', 'Script Commands'))
    
    # Get SE Machine Expert directories
    se_base_dir = os.path.join(
        os.environ.get('PROGRAMFILES', 'C:\\Program Files'),
        'Schneider Electric',
        'EcoStruxure Machine Expert'
    )
    v2_dirs = glob.glob(os.path.join(se_base_dir, 'V2.*'))
    for v2_dir in v2_dirs:
        directories.append(os.path.join(v2_dir, 'LogicBuilder', 'Script Commands'))
    
    return directories

def install_to_directory(path, config_entry, current_dir, just_link=False):
    """Install config and assets to a single directory"""
    print(f"\nInstalling to: {path}")
    
    # Create directory (recursive)
    os.makedirs(path, exist_ok=True)
    
    # Copy icon
    icon_path = os.path.join(current_dir, 'assets', 'export_icon.ico')
    shutil.copy2(icon_path, os.path.join(path, 'export_icon.ico'))
    print(f"Copied export_icon.ico to {path}")
    
    script_path = os.path.join(current_dir, 'cs_export.py')
    if not just_link: # Codesys will refuse to run the script if it's not in ScriptLib or under.
        shutil.copy2(script_path, os.path.join(path, 'cs_export.py'))
        print(f"Copied cs_export.py to {path}")
        config_entry["Path"] = 'cs_export.py'
    else:
        print(f"Linking cs_export.py to {path}")
        config_entry["Path"] = script_path

    # Update or create config.json
    config_dest = os.path.join(path, 'config.json')
    if os.path.exists(config_dest):
        with open(config_dest, 'r') as f:
            config = json.load(f)
        
        for i, entry in enumerate(config):
            if entry.get('Name') == "CodeSys Bridge Script":
                config[i] = config_entry
                print(f"Updated existing CodeSys Bridge Script entry in config.json")
                break
        else:
            config.append(config_entry)
            print(f"Added CodeSys Bridge Script entry to config.json")
    else:
        config = [config_entry]
        print(f"Created new config.json with CodeSys Bridge Script entry")
    
    with open(config_dest, 'w') as f:
        json.dump(config, f, indent=4)

def copy_to_script_commands():
    current_dir = os.path.dirname(os.path.abspath(__file__))
    
    toolbar_export_entry = {
        "Name": "Text Export",
        "Desc": "CodeSys Bridge: Text Export",
        "Icon": "export_icon.ico",
        "Path": ""  # Will be set in install_to_directory
    }
    
    current_dir = os.path.dirname(os.path.abspath(__file__))
    print("Source directory: ", current_dir)

    directories = get_installation_directories()
    
    if not directories:
        print("No installation directories found!")
        return
    
    for directory in directories:
        install_to_directory(directory, toolbar_export_entry.copy(), current_dir, just_link=len(sys.argv) > 1 and sys.argv[1] == "link")

def main():
    if not is_admin():
        # ShellExecuteW returns an HINSTANCE (int) > 32 if successful
        print("Running {} as admin".format(sys.argv[0]))
        args = " ".join(sys.argv[1:]) if len(sys.argv) > 1 else ""
        result = ctypes.windll.shell32.ShellExecuteW(None, "runas", sys.argv[0], args, None, 1)
        if result <= 32:  # Error codes are <= 32
            error_messages = {
                2: "File not found", 
                5: "Access denied",
            }
            error_msg = error_messages.get(result, f"Error code ({result})")
            print(f"Failed to run {sys.argv[0]}: {error_msg}")
            sys.exit(1)
        sys.exit(0)
    
    try:
        print(sys.path)
        copy_to_script_commands()
        print("Successfully installed script commands and assets")
    except Exception as e:
        import traceback
        print(f"Error during installation: {e}")
        traceback.print_exc()
    finally:    
        input("Press Enter to exit...")


if __name__ == "__main__":
    main()
